# Little NN - a tiny deep learning framework

Little NN is my fun project to actually understand the concepts of deep learning `deeply` (pun intended).

Local install:

```bash
pip3 install -e .
```

### @Regards, Alex